pub struct SimpleBPETokenizerConfig { /* private fields */ }Expand description
Configuration for training a simple BPE tokenizer.
This struct implements Trainable and produces a SimpleBPETokenizer.
Implementations
Sourceimpl SimpleBPETokenizerConfig
impl SimpleBPETokenizerConfig
Sourcepub fn build(vocab_size: u32) -> Result<Self, VocabSizeTooSmall>
pub fn build(vocab_size: u32) -> Result<Self, VocabSizeTooSmall>
Create a new configuration for training a simple BPE tokenizer from vocab size.
Sourcepub fn from_merges(merges: u32) -> Self
pub fn from_merges(merges: u32) -> Self
Create a new configuration for training a simple BPE tokenizer from number of merges.