pub struct ParallelRegexBPETokenizerConfig { /* private fields */ }Expand description
Configuration for training a regex-based BPE tokenizer in parallel with rayon.
This struct implements Trainable and produces a ParallelRegexBPETokenizer.
Implementations
Sourceimpl ParallelRegexBPETokenizerConfig
impl ParallelRegexBPETokenizerConfig
Sourcepub fn build(
vocab_size: u32,
pattern: Option<&str>,
) -> Result<Self, RegexBPETokenizerConfigError>
pub fn build( vocab_size: u32, pattern: Option<&str>, ) -> Result<Self, RegexBPETokenizerConfigError>
Create a new configuration for training a regex BPE tokenizer.
Arguments
vocab_size- The desired vocabulary size (must be at least 256).pattern- Optional custom regex pattern. IfNone, uses the GPT-4 split pattern.
Returns
Ok(RegexBPETokenizerConfig)if configuration is valid.Err(RegexBPETokenizerConfigError)if vocab size is too small or pattern is invalid.
Sourcepub fn from_merges(
merges: u32,
pattern: Option<&str>,
) -> Result<Self, RegexBPETokenizerConfigError>
pub fn from_merges( merges: u32, pattern: Option<&str>, ) -> Result<Self, RegexBPETokenizerConfigError>
Create a new configuration from the number of merges instead of vocab size.
Arguments
merges- The number of merge operations to perform.pattern- Optional custom regex pattern.